'''
Version and license information.
'''

__all__ = ['__version__', '__versiondate__', '__license__']

__version__ = '2.0.2'
__versiondate__ = '2020-02-01'
__license__ = f'Covasim {__version__} ({__versiondate__}) — © 2021 by IDM'
